Filesystem

Mostrar tamaño del FS
-k: Emplea unidades de 1024 bytes (1 kB) en lugar de las predeterminadas de 512 bytes.
df -k RUTA
-h: Añade una letra indicativa de tamaño, como M para megabytes binarios (mebibytes), a cada tamaño.
df -h RUTA
Mostrar tamaño de un archivo en GB
ls -lrt --block-size=GB
Mostrar tamaño de una carpeta
du -sh CARPETA
Ordenar por tamaño
Mostrar el tamaño de los archivos que más ocupen y ordenados:
-h / --human-readable: Imprime los datos como: 1K ó 234M ó 2G.
-s: No muestra los subdirectorios.
du -hs * | sort -n
-k / --block-size=1K:
du -ks * | sort -n
Borrar
Para buscar un archivo y borrar los de más de una semana:
-type f: Fichero.
-type d: Carpeta.
-iname: Buscar algo y no distingue mayúsculas de minúsculas.
-mtime: Tiempo a buscar o desde cuando.
-exec: Ejecutar lo siguiente.
find RUTA(si no se pone, es la actual) -type f -iname 'ALGO*' -mtime +X -exec ls -lrt {} \;
find RUTA(si no se pone, es la actual) -type f -iname 'ALGO*' -mtime +X -exec rm -fv {} \;
Vaciar
Vaciar un archivo:
> ALGO
Comprimir
Comprimir sin estar pintando:
gzip -9f ALGO
Comprimir en caliente (pintando ahora mismo):
gzip -c ALGO >> ALGO.gz && > ALGO